@@ -30,10 +30,11 @@ Rule::Rule()
  * @param mod_global Optional global modifier token iterator.
  * @param metas Meta information.
  * @param strings Strings.
+ * @param variables Variables.
  * @param condition Condition expression.
  * @param tags Tags as token iterators.
  */
-Rule::Rule(const std::shared_ptr<TokenStream>& tokenStream, TokenIt name, std::optional<TokenIt> mod_private, std::optional<TokenIt> mod_global, std::vector<Meta>&& metas, std::shared_ptr<StringsTrie>&& strings,
+Rule::Rule(const std::shared_ptr<TokenStream>& tokenStream, TokenIt name, std::optional<TokenIt> mod_private, std::optional<TokenIt> mod_global, std::vector<Meta>&& metas, std::shared_ptr<StringsTrie>&& strings, std::vector<Variable>&& variables, 
 		Expression::Ptr&& condition, const std::vector<TokenIt>& tags)
 	: _tokenStream(tokenStream)
 	, _name(name)
@@ -41,6 +42,7 @@ Rule::Rule(const std::shared_ptr<TokenStream>& tokenStream, TokenIt name, std::o
 	, _mod_global(mod_global)
 	, _metas(std::move(metas))
 	, _strings(std::move(strings))
+	, _variables(std::move(variables))
 	, _condition(std::move(condition))
 	, _tags(tags)
 	, _location({"[stream]", 0})
@@ -97,6 +99,17 @@ std::string Rule::getText() const
 					ss << indent << string->getIdentifier() << " = " << string->getText() << '\n';
 				});
 	}
+
+	if (!getVariables().empty())
+	{
+		ss << "\tvariables:\n";
+		std::for_each(getVariables().begin(), getVariables().end(),
+				[&](const Variable& variable)
+				{
+					ss << indent << variable.getText() << '\n';
+				});
+	}
+
 	ss << "\tcondition:\n" << indent << getCondition()->getText(indent) << "\n}";
 	return ss.str();
 }
@@ -148,6 +161,27 @@ const std::vector<Meta>& Rule::getMetas() const
 	return _metas;
 }
 
+
+/**
+ * Returns the variables of the YARA rule.
+ *
+ * @return Variables.
+ */
+std::vector<Variable>& Rule::getVariables()
+{
+	return _variables;
+}
+
+/**
+ * Returns the variables of the YARA rule.
+ *
+ * @return Variables.
+ */
+const std::vector<Variable>& Rule::getVariables() const
+{
+	return _variables;
+}
+
 /**
  * Returns the strings of the YARA rule.
  *
@@ -281,6 +315,16 @@ void Rule::setMetas(const std::vector<Meta>& metas)
 	_metas = metas;
 }
 
+/**
+ * Sets the variables of the rule.
+ *
+ * @param variables Variables to set.
+ */
+void Rule::setVariables(const std::vector<Variable>& variables)
+{
+	_variables = variables;
+}
+
 /**
  * Sets the tags of the rule.
  *
